roman

package module
v0.0.0-...-11c762c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 8, 2015 License: Apache-2.0 Imports: 1 Imported by: 0

README

Golang Testing Example with Roman Numerals

Build Status Coverage Status

This repository contains an example Golang program used to illustrate table-driven tests, automated build, and unit test code coverage.

The library provides a simple function for converting Roman numerals (in string form) into numbers. It also flags invalid string input.

See the accompanying LICENSE file for usage information.

Documentation

Index

Constants

This section is empty.

Variables

var ErrInvalidFormat = errors.New("Invalid Format")

Functions

func RomanToInt

func RomanToInt(roman string) (int, error)

Types

This section is empty.

Jump to